@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.40 2010/12/23 23:04:56 jasper Exp $
+# $OpenBSD: Quirks.pm,v 1.60 2011/07/20 07:59:28 dcoppa Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -168,49 +168,104 @@ my $stem_extensions = {
 	'gpsd-motif' => 'gpsd-x11',
 	'uuid' => 'ossp-uuid',
 	'p5-UUID' => 'p5-ossp-uuid',
+# 5.0
+	'gqview' => 'geeqie',
+	'openoffice' => 'libreoffice',
+	'openoffice-kde' => 'libreoffice-kde',
+	'openoffice-java' => 'libreoffice-java',
+	'openoffice-i18n-bg' => 'libreoffice-i18n-bg',
+	'openoffice-i18n-ca' => 'libreoffice-i18n-ca',
+	'openoffice-i18n-de' => 'libreoffice-i18n-de',
+	'openoffice-i18n-es' => 'libreoffice-i18n-es',
+	'openoffice-i18n-fa' => 'libreoffice-i18n-fa',
+	'openoffice-i18n-fi' => 'libreoffice-i18n-fi',
+	'openoffice-i18n-fr' => 'libreoffice-i18n-fr',
+	'openoffice-i18n-hu' => 'libreoffice-i18n-hu',
+	'openoffice-i18n-it' => 'libreoffice-i18n-it',
+	'openoffice-i18n-ja' => 'libreoffice-i18n-ja',
+	'openoffice-i18n-ko' => 'libreoffice-i18n-ko',
+	'openoffice-i18n-lt' => 'libreoffice-i18n-lt',
+	'openoffice-i18n-lv' => 'libreoffice-i18n-lv',
+	'openoffice-i18n-nl' => 'libreoffice-i18n-nl',
+	'openoffice-i18n-pl' => 'libreoffice-i18n-pl',
+	'openoffice-i18n-pt-br' => 'libreoffice-i18n-pt-br',
+	'openoffice-i18n-ru' => 'libreoffice-i18n-ru',
+	'openoffice-i18n-sl' => 'libreoffice-i18n-sl',
+	'openoffice-i18n-sv' => 'libreoffice-i18n-sv',
+	'libxfce4menu' => 'garcon',
+	'tidy' => 'tidyp',
+	'p5-Mojo' => 'p5-Mojolicious',
+	'groff-mdoc' => 'groff',
+	'hudson' => 'jenkins',
+	'py-BeautifulSoup' => 'py-beautifulsoup',
+	'hs-network-bytestring' => 'hs-network',
+	'hs-xhtml' => 'ghc',
+	'tomboy' => 'gnote',
+	'dovecot-sieve' => 'dovecot-pigeonhole',
+	'wormux' => 'warmux',
+	'tightvnc-viewer' => 'ssvnc-viewer',
+	'mozilla-firefox' => 'firefox',
+	'mozilla-thunderbird' => 'thunderbird',
+	'php5-core' => 'php',
+	'php5-bz2' => 'php-bz2',
+	'php5-curl' => 'php-curl',
+	'php5-dba' => 'php-dba',
+	'php5-dbase' => 'php-dbase',
+	'php5-fastcgi' => 'php-fastcgi',
+	'php5-gd' => 'php-gd',
+	'php5-gmp' => 'php-gmp',
+	'php5-imap' => 'php-imap',
+	'php5-ldap' => 'php-ldap',
+	'php5-mbstring' => 'php',
+	'php5-mcrypt' => 'php-mcrypt',
+	'php5-mhash' => 'php-mhash',
+	'php5-mysql' => 'php-mysql',
+	'php5-mysqli' => 'php-mysqli',
+	'php5-ncurses' => 'php-ncurses',
+	'php5-odbc' => 'php-odbc',
+	'php5-pdo_mysql' => 'php-pdo_mysql',
+	'php5-pdo_pgsql' => 'php-pdo_pgsql',
+	'php5-pdo_sqlite' => 'php-pdo_sqlite',
+	'php5-pgsql' => 'php-pgsql',
+	'php5-pspell' => 'php-pspell',
+	'php5-shmop' => 'php-shmop',
+	'php5-soap' => 'php-soap',
+	'php5-snmp' => 'php-snmp',
+	'php5-sqlite' => 'php-sqlite',
+	'php5-sybase_ct' => 'php-sybase_ct',
+	'php5-pdo_dblib' => 'php-pdo_dblib',
+	'php5-mssql' => 'php-mssql',
+	'php5-tidy' => 'php-tidy',
+	'php5-xmlrpc' => 'php-xmlrpc',
+	'php5-xsl' => 'php-xsl',
+	'evolution-plugin-rss' => 'evolution-rss',
+	'sazanami-ttf' => 'ja-sazanami-ttf',
+	'mplus-ttf' => 'ja-mplus-ttf',
+	'kanjistrokeorders-ttf' => 'ja-kanjistrokeorders-ttf',
+	'baekmuk-fonts' => 'ko-baekmuk-fonts',
+	'baekmuk-ttf' => 'ko-baekmuk-ttf',
+	'hanterm-fonts' => 'ko-hanterm-fonts',
+	'pscyr' => 'ru-pscyr',
+	'wqy-zenhei-ttf' => 'zh-wqy-zenhei-ttf',
+	'wqy-bitmapfont' => 'zh-wqy-bitmapfont',
+	'ptsans' => 'ru-ptsans',
+	'py-zeya' => 'zeya'
 };
 
 # ->is_base_system($handle, $state):
 #	checks whether an existing handle is now part of the base system
 #	and thus no longer needed.
 
-sub quick_add
-{
-	my ($plist, $fullname) = @_;
-
-	return unless -f $fullname;
-	my $fname = $fullname;
-	$fname =~ s,^/usr/local/,,;
-	my $o = OpenBSD::PackingElement::File->new($fname);
-	if (-l $fullname) {
-		$o->{symlink} = readlink($fullname);
-	}
-	# avoid checksumming them
-	$o->{nochecksum} = 1;
-	$o->add_object($plist);
-}
-
 sub is_base_system
 {
 	my ($self, $handle, $state) = @_;
-	if ($handle->pkgname =~ m/^texlive_base-2009/) {
-		# we need to alter its packing-list
-		my $plist = OpenBSD::PackingList->from_installation(
-		    $handle->pkgname);
-		require File::Find;
-		File::Find::find(
-		    sub {
-			return unless -f $_;
-			return unless m/\.(base|fmt|map|mem)$/;
-			# quick and dirty pseudo-reg of all dup files
-			quick_add($plist, $File::Find::name);
-		    }, 
-		    '/usr/local/share/texmf-var');
-		quick_add($plist, '/usr/local/share/texmf/web2c/fmtutil.cnf');
-		$plist->to_installation;
-	}
 
 	my $stem = OpenBSD::PackageName::splitstem($handle->pkgname);
+	if ($stem =~ m/^texlive_/) {
+		require OpenBSD::Quirks::texlive;
+		OpenBSD::Quirks::texlive::unfuck($handle, $state);
+	}
+
 	my $test = $base_exceptions->{$stem};
 	if (defined $test) {
 		if (-e $test) {
